# ApPlot

[![Build Status](https://travis-ci.org/a-poor/applot.svg?branch=master)](https://travis-ci.org/a-poor/applot)
[![GitHub license](https://img.shields.io/github/license/a-poor/applot)](https://github.com/a-poor/applot/blob/master/LICENSE)

_A small SVG plotting library written from scratch in Python._

created by Austin Poor

